{#- OZI 0.1
# ozi/templates/github_workflows/cleanup.yml.j2
# SPDX-License-Identifier: Unlicense
-#}
name: cleanup caches by a branch
on:
  pull_request:
    types:
      - closed

permissions: read-all

jobs:
  cleanup:
    runs-on: ubuntu-latest
    permissions:
        id-token: write
        contents: write
        actions: write
    steps:
      - name: Harden Runner
        uses: step-security/harden-runner@17d0e2bd7d51742c71671bd19fa12bdc9d40a3d6 # v2.8.1
        with:
          disable-sudo: true
          egress-policy: block
          allowed-endpoints: >
            api.github.com:443
            github.com:443
            objects.githubusercontent.com:443
            uploads.github.com:443

      - name: Cleanup caches
        run: |
          gh extension install actions/gh-actions-cache

          echo "Fetching list of cache key"
          cacheKeysForPR=$(gh actions-cache list -R $REPO -B $BRANCH -L 100 | cut -f 1 )

          ## Setting this to not fail the workflow while deleting cache keys.
          set +e
          echo "Deleting caches..."
          for cacheKey in $cacheKeysForPR
          do
              gh actions-cache delete $cacheKey -R $REPO -B $BRANCH --confirm
          done
          echo "Done"
        env:
{%- raw %}
          GH_TOKEN: ${{ secrets.GITHUB_TOKEN }}
          REPO: ${{ github.repository }}
          BRANCH: refs/pull/${{ github.event.pull_request.number }}/merge
{%- endraw %}